% Estimation of the Liljencrants-Fant Rd parameter using the MSPD2 based method
%
% DESCRIPTION
%
%  Polarity
%   It is sensitive to the polarity since it is assumed that DC phase is 0 (but can be pi)
%   Using this assumption the FPD of the first harmonic can be used.
%   From some experiment (may require better evaluations), the estimation is more efficient using the FPD
%   of the first harmonic (and thus assume angle(DC)=0).
%
% USAGE
%  rds = gl_estim_rd_mspdsq(wav, sr, f0s);
%  params = gl_estim_rd_mspdsq();
%  rds = gl_estim_rd_mspdsq(wav, sr, f0s, params);
% 
% INPUT
%  wav    : Waveform [Nx1]
%  sr     : Sampling rate of wav [1x1 Hz]
%  f0s    : Estimated fundamental frequencies
%           and their corresponding times
%           [Nx2 HzxSeconds]
%  params : Parameters to use
%
% OUTPUT
%  rds    : Estimated Rd values 
%           and their corresponding times
%           [Mx5 Rd;E;T0[Seconds];confidence;time]
%  params : Used parameters
%
% REFERENCES
%  [1] G. Degottex, A. Roebel and X. Rodet, "Phase Minimization for Glottal Model
%      Estimation", IEEE Transactions on Audio, Speech, and Language Processing,
%      19(5), 1080-1090, july 2011
% 
% AUTHOR
%  Gilles Degottex <gilles.degottex@ircam.fr>
%
% COPYRIGHT
%  Copyright (c) 2011 Ircam-CNRS UMR9912-STMS
%
